@@ -31,8 +31,7 @@ time"
 "$ ds ls -l dataset.nc
 time: 3
 temperature float64 { time }
-time int64 { time }
-"
+time int64 { time }"
 
 "Print a list of variables with an attribute `units`.":
 "$ ds ls dataset.nc a: units
