@@ -97,22 +97,54 @@ def time_dt(time):
 	return [parse_time(t) for t in time]
 
 def merge_var(dd, var, dim):
-	if len(dd) == 0:
-		return None, None
-	x0 = ds.var(dd[0], var)
-	var_meta0 = ds.meta(dd[0], var)
-	dims0 = ds.dims(dd[0], var)
-	var_meta = copy_.deepcopy(var_meta0)
-	if dim in dims0:
-		i = dims0.index(dim)
-		x = np.concatenate(
-			[ds.var(d, var) for d in dd if ds.dims(d, var) == dims0],
-			axis=i
-		)
+	for d in dd:
+		x = ds.var(d, var)
+		if x is None:
+			continue
+		dims0 = ds.dims(d, var)
+		size0 = ds.size(d, var)
+		type_ = ds.type(d, var)
+		dt = misc.type_to_dtype(type_)
+		try: k = dims0.index(dim)
+		except ValueError: k = None
+		break
 	else:
-		var_meta['.dims'] = [dim] + dims0
-		x = np.stack([ds.var(d, var) for d in dd if ds.dims(d, var) == dims0])
-	return x, var_meta
+		return None, None
+	if k is None: # New dimension.
+		n = len(dd)
+		dims = [dim] + dims0
+		size = [n] + size0
+	else: # Existing dimension.
+		n = np.sum([ds.dim(d, dim) for d in dd])
+		dims = dims0
+		size = copy_.deepcopy(size0)
+		size[k] = n
+	x = np.ma.array(np.zeros(size, dt), mask=np.ones(size, bool))
+	i = 0
+	meta = {}
+	for d in dd:
+		x1 = ds.var(d, var)
+		n1 = 1 if k is None else ds.dim(d, dim)
+		if x1 is None:
+			i += n1
+			continue
+		dims1 = ds.dims(d, var)
+		size1 = ds.size(d, var)
+		if dims1 != dims0:
+			raise ValueError('merge: incompatible dimensions in variable "%s"' % var)
+		if len(size0) != len(size1) or \
+		   not all(i == k or size1[i] == size0[i] for i in range(len(size0))):
+			raise ValueError('merge: incompatible size in variable "%s"' % var)
+		if k is None:
+			sel = [i] + [slice(None) for j in range(len(size0))]
+		else:
+			sel = [slice(i, i + n1) if j == k else slice(None) \
+				for j in range(len(size))]
+		x[tuple(sel)] = x1
+		meta.update(ds.meta(d, var))
+		i += n1
+	meta['.dims'] = dims
+	return x, meta
 
 def copy(d):
 	d2 = {}
@@ -255,7 +287,7 @@ def dims(d, var=None, *value, full=False, size=False):
 	}}
 	options: {{
 		*var*: "Variable name (`str`) or `None` to get dimensions for."
-		*full*: "Get variable dimensions even if the variable is only defined in the matadata (`bool`)."
+		*full*: "Get variable dimensions even if the variable is only defined in the metadata (`bool`)."
 		*size*: "Return a dictionary containing dimension sizes instead of a list."
 	}}
 	returns: "If *size* is False, a list of dataset or variable dimension names (`list` of `str`). If *size* is True, a dictionary of dataset or variable dimension names and sizes (`dict`), where a key is a dimension name (`str`) and the value is the dimension size (`int`). The order of keys in the dictionary is not guaranteed. Dataset dimensions are the dimensions of all variables together."
@@ -468,7 +500,7 @@ def merge(dd, dim, new=None, variables=None):
 	title: merge
 	caption: "Merge datasets along a dimension."
 	usage: "`merge`(*dd*, *dim*, *new*=`None`, *variables*=`None`)"
-	desc: "Merge datasets along a dimension *dim*. If the dimension is not defined in the dataset, merge along a new dimension *dim*. If *new* is None and *dim* is not new, variables without the dimension are set with the first occurrence of the variable. If *new* is not None and *dim* is not new, variables without the dimension *dim* are merged along a new dimension *new*. If *variables* is not None, only those variables are merged along a new dimension and other variables are set to the first occurrence of the variable."
+	desc: "Merge datasets along a dimension *dim*. If the dimension is not defined in the dataset, merge along a new dimension *dim*. If *new* is None and *dim* is not new, variables without the dimension *dim* are set with the first occurrence of the variable. If *new* is not None and *dim* is not new, variables without the dimension *dim* are merged along a new dimension *new*. If *variables* is not None, only those variables are merged along a new dimension, and other variables are set to the first occurrence of the variable. Variables which are merged along a new dimension and are not present in all datasets have their subsets corresponding to the datasets where they are missing filled with missing values. Dataset and variable metadata are merged sequentially from all datasets, with metadata from later datasets overriding metadata from the former ones."
 	arguments: {{
 		*dd*: "Datasets (`list`)."
 		*dim*: "Name of a dimension to merge along (`str`)."
@@ -500,11 +532,15 @@ $ print(d['temperature'])
 	check(new, 'new', [str, None])
 	check(variables, 'variables', [[list, str], [tuple, str], None])
 	dx = {'.': {'.': {}}}
-	vars_ = list(set([x for d in dd for x in ds.vars(d)]))
+	vars_ = sorted(list(set([x for d in dd for x in ds.vars(d)])))
 	dims = [k for d in dd for k in ds.dims(d)]
 	is_new = dim not in dims
 	for var in vars_:
-		var_dims = ds.dims(dd[0], var)
+		var_dims = None
+		for d in dd:
+			if var in ds.vars(d):
+				var_dims = ds.dims(d, var)
+				break
 		if is_new and (variables is None or var in variables) or \
 		   dim in var_dims:
 			x, meta = merge_var(dd, var, dim)
@@ -515,8 +551,8 @@ $ print(d['temperature'])
 		ds.var(dx, var, x)
 		ds.meta(dx, var, meta)
 	for d in dd:
-		if '.' in d['.']:
-			dx['.']['.'].update(d['.']['.'])
+		meta = ds.meta(d, '')
+		dx['.']['.'].update(meta)
 	return dx
 
 def meta(d, var=None, *value, create=False):
@@ -531,7 +567,7 @@ def meta(d, var=None, *value, create=False):
 	options: {{
 		*var*: "Variable name (`str`), or `None` to get dataset metadata, or an empty string to get dataset attributes."
 		*value*: "Metadata to set (`dict`) or `None` to get metadata."
-		*create*: "Create (modifyable/bound) metadata dictionary in the dataset if not defined (`bool`). If `False`, the returned dictionary is an empty unbound dictionary if it is not already present in the dataset."
+		*create*: "Create (modifiable/bound) metadata dictionary in the dataset if not defined (`bool`). If `False`, the returned dictionary is an empty unbound dictionary if it is not already present in the dataset."
 	}}
 	returns: "Metadata (`dict`)."
 	examples: {{
@@ -888,7 +924,7 @@ def type_(d, var, *value):
 	arguments: {{
 		*d*: "Dataset (`dict`)."
 		*var*: "Variable name (`str`)."
-		*value*: "Variable type (`str`). One of: `float32` and `float64` (32-bit and 64-bit floating-point number, resp.), `int8` `int16`, `int32` and `int64` (8-bit, 16-bit, 32-bit and 64-bit integer, resp.), `uint8`, `uint16`, `uint32` and `uint64` (8-bit, 16-bit, 32-bit and 64-bit unsigned integer, resp.), `bool` (boolean), `str` (string) and `unicode` (Unicode)."
+		*value*: "Variable type (`str`). One of: `float32` and `float64` (32-bit and 64-bit floating-point number, resp.), `int8`, `int16`, `int32` and `int64` (8-bit, 16-bit, 32-bit and 64-bit integer, resp.), `uint8`, `uint16`, `uint32` and `uint64` (8-bit, 16-bit, 32-bit and 64-bit unsigned integer, resp.), `bool` (boolean), `str` (string) and `unicode` (Unicode)."
 	}}
 	returns: "Variable type (`str`) or `None` if not defined."
 	examples: {{
@@ -914,7 +950,7 @@ $ print(ds.var(d, 'temperature'))
 		if data is None:
 			meta = ds.meta(d, var)
 			return meta.get('.type', None)
-		return misc.dtype_to_type(data.dtype)
+		return misc.dtype_to_type(data.dtype, data)
 	elif len(value) == 1:
 		check(value[0], 'value', str)
 		meta = ds.meta(d, var, create=True)
@@ -926,6 +962,11 @@ $ print(ds.var(d, 'temperature'))
 		if data is not None:
 			dt = misc.type_to_dtype(value[0])
 			data = data.astype(dt)
+			if value[0] in ('str', 'unicode'):
+				f = lambda x: str(x).encode('utf-8') if value[0] == 'str' \
+					else str
+				with np.nditer(data, op_flags=['readwrite']) as it:
+				   for x in it: x[...] = f(x)
 			ds.var(d, var, data)
 	else:
 		raise TypeError('only one value argument is expected')
